"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("../lib/command");
const flags_1 = require("../lib/flags");
const cli_ux_1 = require("cli-ux");
// eslint-disable-next-line @typescript-eslint/no-var-requires
const { Confirm } = require('enquirer'); // eslint-disable-line quotes
const workflow_1 = require("../lib/workflow");
// eslint-disable-next-line quotes
const debugFn = require("debug");
const utils_1 = require("../lib/utils");
const user_id_1 = tslib_1.__importDefault(require("../lib/user-id"));
const session_1 = require("../lib/session");
const isEmpty_1 = tslib_1.__importDefault(require("lodash/isEmpty"));
const reduce_1 = tslib_1.__importDefault(require("lodash/reduce"));
const difference_1 = tslib_1.__importDefault(require("lodash/difference"));
const find_1 = tslib_1.__importDefault(require("lodash/find"));
const join_1 = tslib_1.__importDefault(require("lodash/join"));
const debug = debugFn(`broadcast`);
class Broadcast extends command_1.Command {
    async run() {
        const { flags, /*argv,*/ raw } = this.parse(Broadcast);
        const token = session_1.getToken();
        if (!(token === null || token === void 0 ? void 0 : token.uuid)) {
            throw new Error(`failed to discover `);
        }
        const subscriber_id = flags[`subscriber-id`];
        const selfId = user_id_1.default(subscriber_id, token === null || token === void 0 ? void 0 : token.uuid);
        const workflowFlags = {
            ...flags,
            name: `broadcast-${utils_1.uuid()}`,
            uri: `relay-local://broadcast`,
            transient: false,
            http: false,
            hidden: true,
        };
        const workflow = workflow_1.createTimerWorkflow(workflowFlags, raw);
        workflow.install = [selfId];
        const allDevices = await this.relay.devices(subscriber_id);
        let targets = [];
        if (flags.everyone) {
            targets = allDevices;
        }
        else {
            if (flags.device) {
                const invalidDevices = difference_1.default(flags.device, allDevices);
                if (!isEmpty_1.default(invalidDevices)) {
                    throw new Error(`Invalid device IDs: ${invalidDevices}`);
                }
                targets = [...targets, ...flags.device];
            }
            if (flags.group) {
                const groups = await this.relay.groups(subscriber_id);
                const allGroupUsers = reduce_1.default(flags.group, (users, groupIdOrName) => {
                    var _a, _b;
                    const groupUsers = (_b = find_1.default((_a = find_1.default(groups, g => (g.group_id === groupIdOrName || g.name === groupIdOrName))) === null || _a === void 0 ? void 0 : _a.subscribers, { subscriber_id })) === null || _b === void 0 ? void 0 : _b.users;
                    groupUsers !== undefined && users.push(...groupUsers);
                    return users;
                }, []);
                targets = [...targets, ...allGroupUsers];
            }
        }
        if (isEmpty_1.default(targets)) {
            throw new Error(`No broadcast targets specified. Use "--everyone", "--group" or "--device"`);
        }
        const _targets = join_1.default(targets, ` `);
        workflow.config.trigger.start.workflow.args = {
            targets: _targets,
            confirmation_required: flags.acknowledgement,
            text: flags.text,
        };
        debug(workflow);
        cli_ux_1.cli.styledObject({
            Who: _targets,
            When: flags.trigger === `immediately` ? `Immediately` : flags.start,
            How: flags.acknowledgement ? `Require Acknowledgement` : `Quick Announcement`,
            What: flags.text,
        });
        const prompt = new Confirm({
            name: `question`,
            message: `Please confirm the details of your broadcast...`,
        });
        if (await prompt.run()) {
            await this.relay.saveWorkflow(workflow);
            cli_ux_1.cli.log(`Broadcast saved!`);
        }
        else {
            cli_ux_1.cli.log(`Broadcast cancelled!`);
        }
    }
}
exports.default = Broadcast;
Object.defineProperty(Broadcast, "hidden", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: true
});
Object.defineProperty(Broadcast, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `Send a broadcast to one or more Relays`
});
Object.defineProperty(Broadcast, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        ...flags_1.subscriber,
        ...flags_1.timerFlags,
        acknowledgement: flags_1.boolean({
            char: `a`,
            default: false,
            allowNo: true,
        }),
        everyone: flags_1.boolean({ char: `y` }),
        group: flags_1.string({
            char: `g`,
            multiple: true,
        }),
        device: flags_1.string({
            char: `d`,
            multiple: true,
        }),
        text: flags_1.string({
            char: `t`,
            required: true,
        })
    }
});
