"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("../lib/command");
// eslint-disable-next-line quotes
const debugFn = require("debug");
const flags = tslib_1.__importStar(require("../lib/flags"));
const cli_ux_1 = require("cli-ux");
const lodash_1 = require("lodash");
const debug = debugFn(`debug`);
class Debug extends command_1.Command {
    async run() {
        const { flags } = this.parse(Debug);
        if (flags.dump) {
            debug(`dump`);
            const session = this.relay.session();
            debug(`session`);
            cli_ux_1.cli.styledJSON(lodash_1.get(session, flags.path || ``, session));
        }
        if (flags.clear) {
            debug(`clear`);
            this.relay.clear();
            this.log(`Relay CLI configuration cleared`);
        }
        if (flags[`refresh-auth`]) {
            try {
                const tokens = await this.relay.refresh();
                cli_ux_1.cli.styledHeader(`Auth token refreshed`);
                cli_ux_1.cli.styledJSON(tokens);
            }
            catch (e) {
                debug(`failed to refresh token`, e);
                cli_ux_1.cli.error(`Failed to refresh token`);
            }
        }
    }
}
exports.default = Debug;
Object.defineProperty(Debug, "hidden", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: true
});
Object.defineProperty(Debug, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `debug Relay CLI configuration`
});
Object.defineProperty(Debug, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        clear: flags.boolean({
            char: `c`,
            default: false,
        }),
        dump: flags.boolean({
            char: `d`,
            default: false,
        }),
        path: flags.string({
            char: `p`,
            dependsOn: [`dump`],
        }),
        [`refresh-auth`]: flags.boolean({
            char: `r`,
            default: false,
        })
    }
});
