"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("../../lib/command");
const lodash_1 = require("lodash");
const cli_ux_1 = require("cli-ux");
// eslint-disable-next-line @typescript-eslint/no-var-requires
const { Confirm } = require('enquirer'); // eslint-disable-line quotes
// eslint-disable-next-line quotes
const debugFn = require("debug");
const session_1 = require("../../lib/session");
const flags = tslib_1.__importStar(require("../../lib/flags"));
const debug = debugFn(`subscriber`);
class SubscriberSet extends command_1.Command {
    async run() {
        const { flags } = this.parse(SubscriberSet);
        if (flags.name) {
            throw new Error(`name not yet implemented`);
        }
        const subscriberId = flags[`subscriber-id`];
        if (subscriberId) {
            debug(`change to explicit subscriber id => ${flags[`subscriber-id`]}`);
            const subscribers = session_1.getSubscribers();
            const newSubscriber = lodash_1.find(subscribers, [`id`, subscriberId]);
            if (newSubscriber) {
                debug(`new default subscriber`, newSubscriber);
                cli_ux_1.cli.log(`Changing default subscriber to ${newSubscriber.name} (${newSubscriber.id})`);
                const prompt = new Confirm({
                    name: `change`,
                    message: `Are you sure?`
                });
                const answer = await prompt.run();
                if (answer) {
                    session_1.saveDefaultSubscriber(newSubscriber);
                }
            }
            else {
                debug(`find resulted in no valid subscriber`);
                cli_ux_1.cli.error(`Subscriber ID not found: ${subscriberId}`);
            }
        }
        else {
            await session_1.resolveSubscriber();
        }
    }
}
exports.default = SubscriberSet;
Object.defineProperty(SubscriberSet, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `set the default subscriber`
});
Object.defineProperty(SubscriberSet, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        [`subscriber-id`]: flags.string({
            char: `s`,
            description: `subscriber id`,
            required: false,
            hidden: false,
            multiple: false,
            exclusive: [`name`]
        }),
        name: flags.string({
            char: `n`,
            description: `subscriber name`,
            required: false,
            hidden: true,
            multiple: false,
            exclusive: [`subscriber-id`]
        })
    }
});
