"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnsetArgsCommand = void 0;
const tslib_1 = require("tslib");
const cli_ux_1 = require("cli-ux");
const lodash_1 = require("lodash");
const command_1 = require("../../../lib/command");
const flags = tslib_1.__importStar(require("../../../lib/flags"));
// eslint-disable-next-line quotes
const debugFn = require("debug");
const debug = debugFn(`workflow`);
class UnsetArgsCommand extends command_1.Command {
    async run() {
        var _a, _b, _c, _d;
        const { argv, flags } = this.parse(UnsetArgsCommand);
        const workflowId = flags[`workflow-id`];
        const subscriberId = flags[`subscriber-id`];
        if (argv.length === 0) {
            this.error(`Usage: relay workflow:args:get ARG\nMust specify ARG.`);
        }
        debug(argv);
        const workflow = await this.relay.workflow(subscriberId, workflowId);
        if (workflow) {
            const unsets = [];
            const args = (_d = (_c = (_b = (_a = workflow === null || workflow === void 0 ? void 0 : workflow.config) === null || _a === void 0 ? void 0 : _a.trigger) === null || _b === void 0 ? void 0 : _b.start) === null || _c === void 0 ? void 0 : _c.workflow) === null || _d === void 0 ? void 0 : _d.args;
            const mappedArgs = lodash_1.reduce(argv, (mappedArgs, arg) => {
                const value = args[arg];
                const type = typeof value;
                if (value !== undefined) {
                    if (type === `string` || type === `number` || type === `boolean`) {
                        mappedArgs.push({ arg, value, type });
                    }
                    else {
                        throw new Error(`arg ${arg} is of invalid type ${type}`);
                    }
                }
                else {
                    unsets.push(arg);
                }
                return mappedArgs;
            }, []);
            if (lodash_1.size(argv) !== lodash_1.size(unsets)) {
                cli_ux_1.cli.styledHeader(`Workflow arguments for ID ${workflowId}`);
                cli_ux_1.cli.table(mappedArgs, {
                    arg: {},
                    value: {},
                    type: {}
                }, {});
            }
            if (!lodash_1.isEmpty(unsets)) {
                cli_ux_1.cli.styledHeader(`Following arguments are not set on Workflow`);
                lodash_1.forEach(unsets, arg => {
                    this.error(`${arg}`);
                });
            }
        }
        else {
            cli_ux_1.cli.log(`Workflow ID does not exist: ${workflowId}`);
        }
    }
}
exports.UnsetArgsCommand = UnsetArgsCommand;
Object.defineProperty(UnsetArgsCommand, "strict", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: false
});
Object.defineProperty(UnsetArgsCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `display a single workflow arguments`
});
Object.defineProperty(UnsetArgsCommand, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        [`workflow-id`]: flags.workflowId,
        ...flags.subscriber,
    }
});
Object.defineProperty(UnsetArgsCommand, "args", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: [
        {
            name: `ARG`,
            required: true,
        }
    ]
});
