"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SetArgsCommand = void 0;
const tslib_1 = require("tslib");
// eslint-disable-next-line eslint-comments/disable-enable-pair
/* eslint-disable @typescript-eslint/no-explicit-any */
const cli_ux_1 = require("cli-ux");
const lodash_1 = require("lodash");
const command_1 = require("../../../lib/command");
const flags = tslib_1.__importStar(require("../../../lib/flags"));
const utils_1 = require("../../../lib/utils");
// eslint-disable-next-line quotes
const debugFn = require("debug");
const debug = debugFn(`workflow`);
class SetArgsCommand extends command_1.Command {
    async run() {
        const parsed = this.parse(SetArgsCommand);
        const { flags, argv, raw } = parsed;
        const workflowId = flags[`workflow-id`];
        const subscriberId = flags[`subscriber-id`];
        // debug(parsed)
        try {
            const normalArgs = lodash_1.reduce(argv, (args, input) => {
                const [success, name, value] = utils_1.parseArg(input);
                if (!success) {
                    cli_ux_1.cli.error(`${input} is invalid. Must be in the format of 'foo=bar'`);
                    cli_ux_1.cli.exit(1);
                }
                args[name] = value;
                return args;
            }, {});
            const booleanFlags = lodash_1.filter(raw, ({ flag }) => `boolean` === flag);
            const booleanArgs = lodash_1.reduce(booleanFlags, (args, flag) => {
                const nameValue = SetArgsCommand.flags.boolean.parse(flag.input, null);
                return { ...args, ...nameValue };
            }, {});
            const numberFlags = lodash_1.filter(raw, ({ flag }) => `number` === flag);
            const numberArgs = lodash_1.reduce(numberFlags, (args, flag) => {
                const nameValue = SetArgsCommand.flags.number.parse(flag.input, null);
                return { ...args, ...nameValue };
            }, {});
            const args = { ...normalArgs, ...booleanArgs, ...numberArgs };
            cli_ux_1.cli.action.start(`Setting args ${lodash_1.join(lodash_1.keys(args), `, `)} on Workflow ID: ${workflowId}`);
            const workflow = await this.relay.workflow(subscriberId, workflowId);
            if (workflow) {
                debug(`existing args`, workflow.config.trigger.start.workflow.args);
                workflow.config.trigger.start.workflow.args = {
                    ...workflow.config.trigger.start.workflow.args,
                    ...args,
                };
                await this.relay.saveWorkflow(workflow);
                cli_ux_1.cli.action.stop(`success`);
                cli_ux_1.cli.styledHeader(`New Workflow arguments`);
                cli_ux_1.cli.styledJSON(workflow.config.trigger.start.workflow.args);
            }
            else {
                cli_ux_1.cli.action.stop(`failed`);
                cli_ux_1.cli.log(`Workflow ID does not exist: ${workflowId}`);
            }
        }
        catch (err) {
            debug(err);
            this.error(err);
        }
    }
}
exports.SetArgsCommand = SetArgsCommand;
Object.defineProperty(SetArgsCommand, "strict", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: false
});
Object.defineProperty(SetArgsCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `set one or more workflow arguments`
});
Object.defineProperty(SetArgsCommand, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        [`workflow-id`]: flags.workflowId,
        boolean: flags.booleanValue(),
        number: flags.numberValue(),
        ...flags.subscriber,
    }
});
