"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnsetArgsCommand = void 0;
const tslib_1 = require("tslib");
const cli_ux_1 = require("cli-ux");
const lodash_1 = require("lodash");
const command_1 = require("../../../lib/command");
const flags = tslib_1.__importStar(require("../../../lib/flags"));
// eslint-disable-next-line quotes
const debugFn = require("debug");
const debug = debugFn(`workflow`);
class UnsetArgsCommand extends command_1.Command {
    async run() {
        const { argv, flags } = this.parse(UnsetArgsCommand);
        const workflowId = flags[`workflow-id`];
        const subscriberId = flags[`subscriber-id`];
        if (argv.length === 0) {
            this.error(`Usage: relay workflow:args:unset KEY1 [KEY2 ...]\nMust specify KEY to unset.`);
        }
        debug(argv);
        cli_ux_1.cli.action.start(`Unsetting args ${lodash_1.join(argv, `, `)} on Workflow ID: ${workflowId}`);
        const workflow = await this.relay.workflow(subscriberId, workflowId);
        if (workflow) {
            debug(`existing args`, workflow.config.trigger.start.workflow.args);
            workflow.config.trigger.start.workflow.args = lodash_1.omit(workflow.config.trigger.start.workflow.args, argv);
            await this.relay.saveWorkflow(workflow);
            cli_ux_1.cli.action.stop(`success`);
            cli_ux_1.cli.styledHeader(`New Workflow arguments`);
            cli_ux_1.cli.styledJSON(workflow.config.trigger.start.workflow.args);
        }
        else {
            cli_ux_1.cli.action.stop(`failed`);
            cli_ux_1.cli.log(`Workflow ID does not exist: ${workflowId}`);
        }
    }
}
exports.UnsetArgsCommand = UnsetArgsCommand;
Object.defineProperty(UnsetArgsCommand, "strict", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: false
});
Object.defineProperty(UnsetArgsCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `unset one or more workflow arguments`
});
Object.defineProperty(UnsetArgsCommand, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        [`workflow-id`]: flags.workflowId,
        ...flags.subscriber,
    }
});
