"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BatteryWorkflowCommand = void 0;
const command_1 = require("../../../lib/command");
const flags_1 = require("../../../lib/flags");
// eslint-disable-next-line quotes
const debugFn = require("debug");
const workflow_1 = require("../../../lib/workflow");
const debug = debugFn(`workflow:create:battery`);
const mapTap = (tap) => `on_battery_${tap}`;
class BatteryWorkflowCommand extends command_1.Command {
    async run() {
        const { flags, raw } = this.parse(BatteryWorkflowCommand);
        try {
            const workflow = workflow_1.createWorkflow(flags, raw);
            if (!flags.trigger) {
                throw new Error(`Trigger type battery requires specifying a trigger of charge or discharge. For instance '--trigger discharge'`);
            }
            else if (!(flags.threshold > 0)) {
                throw new Error(`Trigger type battery requires specifying a threshold percentage as an integer. For instance '--threshold 25'`);
            }
            else {
                workflow.config.trigger[mapTap(flags.trigger)] = flags.threshold;
            }
            debug(workflow);
            const workflows = await this.relay.saveWorkflow(workflow);
            workflow_1.printWorkflows(workflows);
        }
        catch (err) {
            debug(err);
            this.error(err);
        }
    }
}
exports.BatteryWorkflowCommand = BatteryWorkflowCommand;
Object.defineProperty(BatteryWorkflowCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `Create or update a workflow triggered by crossing a charging or discharging threshold of any device on the account`
});
Object.defineProperty(BatteryWorkflowCommand, "strict", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: false
});
Object.defineProperty(BatteryWorkflowCommand, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        ...flags_1.workflowFlags,
        trigger: flags_1.enum({
            required: true,
            multiple: false,
            default: `discharge`,
            options: [`charge`, `discharge`],
            description: `Trigger whether threshold value is reached when charging or discharging`,
        }),
        threshold: flags_1.integer({
            required: true,
            multiple: false,
            default: 25,
            description: `Threshold percentage as an integer to trigger workflow`,
        }),
    }
});
