"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ButtonWorkflowCommand = void 0;
const command_1 = require("../../../lib/command");
const flags_1 = require("../../../lib/flags");
// eslint-disable-next-line quotes
const debugFn = require("debug");
const workflow_1 = require("../../../lib/workflow");
const debug = debugFn(`workflow:create:button`);
const mapTap = (tap) => `action_button_${tap}_tap`;
class ButtonWorkflowCommand extends command_1.Command {
    async run() {
        const { flags, raw } = this.parse(ButtonWorkflowCommand);
        try {
            const workflow = workflow_1.createWorkflow(flags, raw);
            if (flags.trigger) {
                workflow.config.trigger.on_button = mapTap(flags.trigger);
            }
            else {
                throw new Error(`Trigger type button requires specifying number of taps. For instance '--trigger single'`);
            }
            debug(workflow);
            const workflows = await this.relay.saveWorkflow(workflow);
            workflow_1.printWorkflows(workflows);
        }
        catch (err) {
            debug(err);
            this.error(err);
        }
    }
}
exports.ButtonWorkflowCommand = ButtonWorkflowCommand;
Object.defineProperty(ButtonWorkflowCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `Create or update a workflow triggered by button taps`
});
Object.defineProperty(ButtonWorkflowCommand, "strict", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: false
});
Object.defineProperty(ButtonWorkflowCommand, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        ...flags_1.workflowFlags,
        trigger: flags_1.enum({
            required: true,
            multiple: false,
            default: `single`,
            options: [`single`, `double`],
            description: `Number of button taps to trigger this workflow`,
        }),
    }
});
