"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CallWorkflowCommand = void 0;
const command_1 = require("../../../lib/command");
const flags_1 = require("../../../lib/flags");
// eslint-disable-next-line quotes
const debugFn = require("debug");
const workflow_1 = require("../../../lib/workflow");
const debug = debugFn(`workflow:create:call`);
const types = {
    inbound: `on_incoming_call`,
    outbound: `on_call_request`,
};
const mapType = (type) => types[type];
class CallWorkflowCommand extends command_1.Command {
    async run() {
        const { flags, raw } = this.parse(CallWorkflowCommand);
        try {
            const workflow = workflow_1.createWorkflow(flags, raw);
            if (!flags.trigger) {
                throw new Error(`Trigger type call requires specifying a trigger of inbound or outbound. For instance '--trigger outbound'`);
            }
            else {
                workflow.config.trigger[mapType(flags.trigger)] = `.*`;
            }
            debug(workflow);
            const workflows = await this.relay.saveWorkflow(workflow);
            workflow_1.printWorkflows(workflows);
        }
        catch (err) {
            debug(err);
            this.error(err);
        }
    }
}
exports.CallWorkflowCommand = CallWorkflowCommand;
Object.defineProperty(CallWorkflowCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `Create or update a workflow triggered by inbound or outbound calling`
});
Object.defineProperty(CallWorkflowCommand, "strict", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: false
});
Object.defineProperty(CallWorkflowCommand, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        ...flags_1.workflowFlags,
        trigger: flags_1.enum({
            required: true,
            multiple: false,
            default: `outbound`,
            options: [`inbound`, `outbound`],
            description: `Trigger whether an inbound or outbound call is placed`,
        }),
    }
});
