"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventWorkflowCommand = void 0;
const command_1 = require("../../../lib/command");
const flags_1 = require("../../../lib/flags");
// eslint-disable-next-line quotes
const debugFn = require("debug");
const workflow_1 = require("../../../lib/workflow");
const debug = debugFn(`workflow:create:event`);
const mapTap = (event) => `${event}`;
class EventWorkflowCommand extends command_1.Command {
    async run() {
        const { flags, raw } = this.parse(EventWorkflowCommand);
        try {
            const workflow = workflow_1.createWorkflow(flags, raw);
            if (flags.trigger) {
                workflow.config.trigger.on_device_event = mapTap(flags.trigger);
            }
            else {
                throw new Error(`Trigger type event requires specifying a device event. For instance '--trigger emergency'`);
            }
            debug(workflow);
            const workflows = await this.relay.saveWorkflow(workflow);
            workflow_1.printWorkflows(workflows);
        }
        catch (err) {
            debug(err);
            this.error(err);
        }
    }
}
exports.EventWorkflowCommand = EventWorkflowCommand;
Object.defineProperty(EventWorkflowCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `Create or update a workflow triggered by event emitted by Relay device`
});
Object.defineProperty(EventWorkflowCommand, "strict", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: false
});
Object.defineProperty(EventWorkflowCommand, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        ...flags_1.workflowFlags,
        trigger: flags_1.enum({
            required: true,
            multiple: false,
            default: `emergency`,
            options: [`emergency`,],
            description: `Relay device event to trigger this workflow`,
        }),
    }
});
