"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpWorkflowCommand = void 0;
const command_1 = require("../../../lib/command");
const flags_1 = require("../../../lib/flags");
// eslint-disable-next-line quotes
const debugFn = require("debug");
const workflow_1 = require("../../../lib/workflow");
const debug = debugFn(`workflow:create:http`);
const mapTap = (method) => `${method}`;
class HttpWorkflowCommand extends command_1.Command {
    async run() {
        const { flags, raw } = this.parse(HttpWorkflowCommand);
        try {
            const workflow = workflow_1.createWorkflow(flags, raw);
            if (flags.trigger) {
                workflow.config.trigger.on_http = mapTap(flags.trigger);
            }
            else {
                throw new Error(`Trigger type http requires specifying an HTTP method. For instance '--trigger POST'`);
            }
            debug(workflow);
            const workflows = await this.relay.saveWorkflow(workflow);
            workflow_1.printWorkflows(workflows);
        }
        catch (err) {
            debug(err);
            this.error(err);
        }
    }
}
exports.HttpWorkflowCommand = HttpWorkflowCommand;
Object.defineProperty(HttpWorkflowCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `Create or update a workflow triggered by an HTTP request`
});
Object.defineProperty(HttpWorkflowCommand, "strict", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: false
});
Object.defineProperty(HttpWorkflowCommand, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        ...flags_1.workflowFlags,
        trigger: flags_1.enum({
            required: true,
            multiple: false,
            default: `POST`,
            options: [`POST`,],
            description: `HTTP method to trigger this workflow`,
        }),
    }
});
