"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PhraseWorkflowCommand = void 0;
const command_1 = require("../../../lib/command");
const flags_1 = require("../../../lib/flags");
// eslint-disable-next-line quotes
const debugFn = require("debug");
const workflow_1 = require("../../../lib/workflow");
const debug = debugFn(`workflow:create:phrase`);
class PhraseWorkflowCommand extends command_1.Command {
    async run() {
        const { flags, raw } = this.parse(PhraseWorkflowCommand);
        try {
            const workflow = workflow_1.createWorkflow(flags, raw);
            if (flags.trigger) {
                workflow.config.trigger.on_phrase = flags.trigger;
            }
            else {
                throw new Error(`Trigger type phrase requires specifying a phrase. For instance '--phrase hello'`);
            }
            debug(workflow);
            const workflows = await this.relay.saveWorkflow(workflow);
            workflow_1.printWorkflows(workflows);
        }
        catch (err) {
            debug(err);
            this.error(err);
        }
    }
}
exports.PhraseWorkflowCommand = PhraseWorkflowCommand;
Object.defineProperty(PhraseWorkflowCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `Create or update a workflow triggered by a spoken phrase`
});
Object.defineProperty(PhraseWorkflowCommand, "strict", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: false
});
Object.defineProperty(PhraseWorkflowCommand, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        ...flags_1.workflowFlags,
        trigger: flags_1.string({
            required: true,
            multiple: false,
            description: `Phrase spoken to Relay Assistant to trigger this workflow`,
            helpValue: `"hello world"`
        }),
    }
});
