"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeleteWorkflowCommand = void 0;
const tslib_1 = require("tslib");
const cli_ux_1 = require("cli-ux");
const command_1 = require("../../lib/command");
const flags = tslib_1.__importStar(require("../../lib/flags"));
// eslint-disable-next-line quotes
const debugFn = require("debug");
const debug = debugFn(`workflow`);
// eslint-disable-next-line @typescript-eslint/no-var-requires
const { Confirm } = require('enquirer'); // eslint-disable-line quotes
class DeleteWorkflowCommand extends command_1.Command {
    async run() {
        const { flags } = this.parse(DeleteWorkflowCommand);
        const workflowId = flags[`workflow-id`];
        const subscriberId = flags[`subscriber-id`];
        try {
            const workflow = await this.relay.workflow(subscriberId, workflowId);
            debug(workflow);
            if (workflow) {
                const prompt = new Confirm({
                    name: `question`,
                    message: `Deleting ${workflow.name} (ID: ${workflowId}). Are you sure?`
                });
                const answer = await prompt.run();
                if (answer) {
                    const success = await this.relay.removeWorkflow(workflow.workflow_id);
                    if (success) {
                        cli_ux_1.cli.log(`Workflow deleted`);
                    }
                    else {
                        cli_ux_1.cli.log(`Workflow NOT deleted`);
                    }
                }
                else {
                    cli_ux_1.cli.log(`Workflow NOT deleted`);
                }
            }
            else {
                cli_ux_1.cli.log(`Workflow ID does not exist: ${workflowId}`);
            }
        }
        catch (err) {
            debug(err);
            this.error(err);
        }
    }
}
exports.DeleteWorkflowCommand = DeleteWorkflowCommand;
Object.defineProperty(DeleteWorkflowCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `Destructively delete and remove a workflow`
});
Object.defineProperty(DeleteWorkflowCommand, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        [`workflow-id`]: flags.workflowId,
        ...flags.subscriber,
    }
});
