"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InstallWorkflowCommand = void 0;
const tslib_1 = require("tslib");
const cli_ux_1 = require("cli-ux");
const lodash_1 = require("lodash");
const command_1 = require("../../lib/command");
const flags = tslib_1.__importStar(require("../../lib/flags"));
// eslint-disable-next-line quotes
const debugFn = require("debug");
const debug = debugFn(`workflow`);
class InstallWorkflowCommand extends command_1.Command {
    async run() {
        const { flags, argv } = this.parse(InstallWorkflowCommand);
        const workflowId = flags[`workflow-id`];
        const subscriberId = flags[`subscriber-id`];
        try {
            cli_ux_1.cli.action.start(`Installing Workflow ${workflowId} on ${lodash_1.join(argv, `, `)}`);
            const workflow = await this.relay.workflow(subscriberId, workflowId);
            if (workflow) {
                debug(`existing install`, workflow.install);
                workflow.install = [...workflow.install, ...argv];
                await this.relay.saveWorkflow(workflow);
                cli_ux_1.cli.action.stop(`success`);
                cli_ux_1.cli.styledHeader(`Workflow now installed on`);
                cli_ux_1.cli.styledJSON(workflow.install);
            }
            else {
                cli_ux_1.cli.action.stop(`failed`);
                cli_ux_1.cli.log(`Workflow ID does not exist: ${workflowId}`);
            }
        }
        catch (err) {
            debug(err);
            if (err.statusCode === 400 && err.body.error === `invalid_install_user_id`) {
                this.error(`One or more of IDs is not valid`);
            }
            else {
                this.error(err);
            }
        }
    }
}
exports.InstallWorkflowCommand = InstallWorkflowCommand;
Object.defineProperty(InstallWorkflowCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `Install an existing workflow into one or more devices`
});
Object.defineProperty(InstallWorkflowCommand, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        [`workflow-id`]: flags.workflowId,
        ...flags.subscriber,
    }
});
Object.defineProperty(InstallWorkflowCommand, "args", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: [
        {
            name: `ID`,
            required: true,
            description: `device / user ID to install workflow on`,
        }
    ]
});
