"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const command_1 = require("../../lib/command");
const isEmpty_1 = tslib_1.__importDefault(require("lodash/isEmpty"));
const utils_1 = require("../../lib/utils");
const flags = tslib_1.__importStar(require("../../lib/flags"));
// eslint-disable-next-line quotes
const debugFn = require("debug");
const debug = debugFn(`workflow`);
class Workflow extends command_1.Command {
    async run() {
        const { flags } = this.parse(Workflow);
        try {
            const workflows = await this.relay.workflows(flags[`subscriber-id`]);
            debug(workflows);
            if (!isEmpty_1.default(workflows)) {
                cli_ux_1.default.styledHeader(`Installed Workflows`);
                cli_ux_1.default.table(workflows, {
                    workflow_id: {
                        header: `ID`,
                        get: row => row.workflow_id //last(row.workflow_id.split(`_`))
                    },
                    name: {},
                    type: {
                        get: utils_1.formatWorkflowType,
                    },
                    uri: {
                        get: row => row.config.trigger.start.workflow.uri,
                        extended: true,
                    },
                    args: {
                        get: utils_1.formatWorkflowArgs,
                        extended: true,
                    },
                    install: {
                        header: `Installed on`,
                        get: row => row.install.join(`\n`),
                        extended: true
                    }
                }, {
                    printLine: this.log,
                    ...flags,
                });
            }
            else {
                this.log(`No Workflows have been created yet`);
            }
        }
        catch (err) {
            debug(err);
            this.error(err);
        }
    }
}
exports.default = Workflow;
Object.defineProperty(Workflow, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `List workflow configurations`
});
Object.defineProperty(Workflow, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        ...flags.subscriber,
        ...cli_ux_1.default.table.flags(),
    }
});
