"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UninstallWorkflowCommand = void 0;
const tslib_1 = require("tslib");
const cli_ux_1 = require("cli-ux");
const lodash_1 = require("lodash");
const command_1 = require("../../lib/command");
const flags = tslib_1.__importStar(require("../../lib/flags"));
// eslint-disable-next-line quotes
const debugFn = require("debug");
const debug = debugFn(`workflow`);
class UninstallWorkflowCommand extends command_1.Command {
    async run() {
        const { flags, argv } = this.parse(UninstallWorkflowCommand);
        const workflowId = flags[`workflow-id`];
        const subscriberId = flags[`subscriber-id`];
        try {
            cli_ux_1.cli.action.start(`Uninstalling Workflow ${workflowId} on ${lodash_1.join(argv, `, `)}`);
            const workflow = await this.relay.workflow(subscriberId, workflowId);
            if (workflow) {
                debug(`existing install`, workflow.install);
                workflow.install = lodash_1.filter(workflow.install, i => !lodash_1.includes(argv, i));
                await this.relay.saveWorkflow(workflow);
                cli_ux_1.cli.action.stop(`success`);
                cli_ux_1.cli.styledHeader(`Workflow now installed on`);
                cli_ux_1.cli.styledJSON(workflow.install);
            }
            else {
                cli_ux_1.cli.action.stop(`failed`);
                cli_ux_1.cli.log(`Workflow ID does not exist: ${workflowId}`);
            }
        }
        catch (err) {
            debug(err);
            this.error(err);
        }
    }
}
exports.UninstallWorkflowCommand = UninstallWorkflowCommand;
Object.defineProperty(UninstallWorkflowCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: `Uninstall an existing workflow from one or more devices`
});
Object.defineProperty(UninstallWorkflowCommand, "flags", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        [`workflow-id`]: flags.workflowId,
        ...flags.subscriber,
    }
});
Object.defineProperty(UninstallWorkflowCommand, "args", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: [
        {
            name: `ID`,
            required: true,
            description: `device / user ID to uninstall workflow on`,
        }
    ]
});
