import * as Config from '@oclif/config';
import { CLIError } from '@oclif/errors';
import { HTTP, HTTPError, HTTPRequestOptions } from 'http-call';
import { Session, Subscriber, TokenAccount } from './session';
import { DeviceId, Group, NewWorkflow, Workflow } from './api';
export declare namespace APIClient {
    interface Options extends HTTPRequestOptions {
        retryAuth?: boolean;
    }
}
export interface IOptions {
    required?: boolean;
    preauth?: boolean;
}
export interface APIErrorOptions {
    resource?: string;
    id?: string;
    message?: string;
    url?: string;
}
export declare class APIError extends CLIError {
    http: HTTPError;
    body: APIErrorOptions;
    constructor(httpError: HTTPError);
}
export declare class APIClient {
    protected config: Config.IConfig;
    options: IOptions;
    authPromise?: Promise<TokenAccount>;
    http: typeof HTTP;
    private readonly _login;
    private _auth?;
    constructor(config: Config.IConfig, options?: IOptions);
    get auth(): string | undefined;
    set auth(token: string | undefined);
    refresh(): Promise<TokenAccount>;
    get<T>(url: string, options?: APIClient.Options): Promise<HTTP<T>>;
    post<T>(url: string, options?: APIClient.Options): Promise<HTTP<T>>;
    put<T>(url: string, options?: APIClient.Options): Promise<HTTP<T>>;
    delete<T>(url: string, options?: APIClient.Options): Promise<HTTP<T>>;
    request<T>(url: string, options?: APIClient.Options): Promise<HTTP<T>>;
    login(): Promise<TokenAccount>;
    logout(): Promise<void>;
    get defaults(): typeof HTTP.defaults;
    whoami(): Promise<Record<string, string>>;
    devices(subscriberId: string): Promise<DeviceId[]>;
    groups(subscriberId: string): Promise<Group[]>;
    workflows(subscriberId: string): Promise<Workflow[]>;
    workflow(subscriberId: string, id: string): Promise<Workflow | undefined>;
    saveWorkflow(workflow: NewWorkflow): Promise<Workflow[]>;
    removeWorkflow(id: string): Promise<boolean>;
    triggerWorkflow(subscriberId: string, workflowId: string, args: Record<string, string>): Promise<void>;
    clear(): void;
    session(): Session;
    subscribers(): Promise<Subscriber[]>;
}
