"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveSubscriber = exports.getDefaultSubscriberId = exports.getDefaultSubscriber = exports.saveDefaultSubscriber = exports.getSubscribers = exports.saveSubscribers = exports.setToken = exports.getToken = exports.clearSubscribers = exports.deleteSession = exports.clearConfig = exports.getSession = void 0;
const tslib_1 = require("tslib");
const lodash_1 = require("lodash");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const debug_1 = tslib_1.__importDefault(require("debug"));
const deps_1 = tslib_1.__importDefault(require("./deps"));
const vars_1 = require("./vars");
// eslint-disable-next-line @typescript-eslint/no-var-requires
const { AutoComplete, Select } = require('enquirer'); // eslint-disable-line quotes
const debug = debug_1.default(`login`);
const getSession = () => {
    return deps_1.default.config.get(`session`);
};
exports.getSession = getSession;
const clearConfig = () => {
    deps_1.default.config.clear();
};
exports.clearConfig = clearConfig;
const deleteSession = () => {
    deps_1.default.config.delete(`session`);
};
exports.deleteSession = deleteSession;
const clearSubscribers = () => {
    deps_1.default.susbscriberConfig.clear();
};
exports.clearSubscribers = clearSubscribers;
const getToken = (host = vars_1.vars.apiHost) => {
    const tokens = deps_1.default.config.get(`session.tokens`);
    return tokens === null || tokens === void 0 ? void 0 : tokens[host];
};
exports.getToken = getToken;
const setToken = (token, host = vars_1.vars.apiHost) => {
    const tokens = (deps_1.default.config.get(`session.tokens`) || {});
    tokens[host] = token;
    deps_1.default.config.set(`session.tokens`, tokens);
};
exports.setToken = setToken;
const saveSubscribers = (subscribers) => {
    deps_1.default.susbscriberConfig.set(`all`, subscribers);
};
exports.saveSubscribers = saveSubscribers;
const getSubscribers = () => {
    const subscribers = deps_1.default.susbscriberConfig.get(`all`);
    if (lodash_1.isEmpty(subscribers)) {
        throw new Error(`no saved subscribers`);
    }
    return subscribers;
};
exports.getSubscribers = getSubscribers;
const saveDefaultSubscriber = (subscriber) => {
    deps_1.default.config.set(`session.subscriber`, subscriber);
};
exports.saveDefaultSubscriber = saveDefaultSubscriber;
const getDefaultSubscriber = () => {
    const subscriber = deps_1.default.config.get(`session.subscriber`);
    if (subscriber === undefined) {
        throw new Error(`no default subscriber set`);
    }
    else {
        return subscriber;
    }
};
exports.getDefaultSubscriber = getDefaultSubscriber;
const getDefaultSubscriberId = () => {
    return exports.getDefaultSubscriber().id;
};
exports.getDefaultSubscriberId = getDefaultSubscriberId;
const resolveSubscriber = async (subscribers = exports.getSubscribers()) => {
    debug(subscribers);
    const subscribersSize = lodash_1.size(subscribers);
    if (subscribersSize === 1 && subscribers[0]) {
        exports.saveDefaultSubscriber(subscribers[0]);
        return true;
    }
    else {
        const selector = (subscribersSize > 25) ? AutoComplete : Select;
        const subscriberPrompt = new selector({
            multiple: false,
            name: `subscriber`,
            message: `Pick your default Relay account`,
            choices: lodash_1.map(subscribers, (subscriber, value) => ({ name: `${subscriber.name} (${subscriber.id})`, value })),
            limit: 10,
        });
        const subscriberIdx = await subscriberPrompt.run();
        debug(`choosen index`, subscriberIdx);
        const subscriber = subscribers[subscriberIdx];
        if (subscriber) {
            debug(`choosen subscriber`, subscriber);
            exports.saveDefaultSubscriber(subscriber);
            if (subscribersSize > 1) {
                cli_ux_1.default.log(`=====================`);
                cli_ux_1.default.log(`Default Relay Account`);
                cli_ux_1.default.log(`${subscriber.name} (${subscriber.id})`);
                cli_ux_1.default.log(`=====================`);
            }
            return true;
        }
        else {
            return false;
        }
    }
};
exports.resolveSubscriber = resolveSubscriber;
