"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.base64url = exports.uuid = exports.s4 = exports.getOrThrow = exports.formatWorkflowType = exports.parseArg = exports.formatWorkflowArgs = void 0;
const lodash_1 = require("lodash");
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
const formatWorkflowArgs = (workflow, json = false) => {
    var _a, _b, _c, _d;
    const args = ((_d = (_c = (_b = (_a = workflow === null || workflow === void 0 ? void 0 : workflow.config) === null || _a === void 0 ? void 0 : _a.trigger) === null || _b === void 0 ? void 0 : _b.start) === null || _c === void 0 ? void 0 : _c.workflow) === null || _d === void 0 ? void 0 : _d.args) || {};
    if (json) {
        return JSON.stringify(args, null, 2);
    }
    else {
        const strings = lodash_1.map(args, (value, arg) => (`${arg}=${value} | ${typeof value}`));
        return lodash_1.join(strings, `\n`);
    }
};
exports.formatWorkflowArgs = formatWorkflowArgs;
const parseArg = (input) => {
    const idx = lodash_1.indexOf(input, `=`);
    if (idx === -1) {
        return [false, input];
    }
    const name = input.slice(0, idx);
    const value = input.slice(idx + 1);
    return [true, name, value];
};
exports.parseArg = parseArg;
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
const formatWorkflowType = (workflow) => {
    const type = lodash_1.find(lodash_1.keys(workflow.config.trigger), key => lodash_1.startsWith(key, `on_`));
    if (type) {
        const trigger = workflow.config.trigger[type];
        switch (type) {
            case `on_device_event`: {
                return `device:${trigger}`;
            }
            case `on_phrase`: {
                return `phrase:${lodash_1.isArray(trigger) ? lodash_1.join(trigger, `,`) : trigger}`;
            }
            case `on_button`: {
                return `button:${lodash_1.replace(trigger, /action_button_|_tap/g, ``)}`;
            }
            case `on_call_request`: {
                return `call:outbound`;
            }
            case `on_incoming_call`: {
                return `call:inbound`;
            }
            case `on_timer`: {
                return `timer`;
            }
            case `on_battery_discharge`: {
                return `battery:discharge:${trigger}`;
            }
            case `on_battery_charge`: {
                return `battery:charge:${trigger}`;
            }
            case `on_http`: {
                return `http:${trigger}`;
            }
        }
    }
    return `unknown`;
};
exports.formatWorkflowType = formatWorkflowType;
function getOrThrow(obj, path) {
    const value = lodash_1.get(obj, path);
    if (lodash_1.isEmpty(value)) {
        throw new Error(`required string is undefined, null, or empty`);
    }
    return value;
}
exports.getOrThrow = getOrThrow;
function s4() {
    return Math.floor((1 + Math.random()) * 0x10000)
        .toString(16)
        .substring(1);
}
exports.s4 = s4;
function uuid() {
    return lodash_1.join(lodash_1.times(11, s4), `_`);
}
exports.uuid = uuid;
function base64url(str) {
    return str.replace(/\+/g, `-`).replace(/\//g, `_`).replace(/=+$/, ``);
}
exports.base64url = base64url;
