"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.vars = exports.Vars = void 0;
const url_1 = require("url");
const config = {
    qa: {
        host: `all-api-qa-ibot.nocell.io`,
        authHost: `auth.relaygo.info`,
        id: `4EgeETYm`,
    },
    pro: {
        host: `all-main-pro-ibot.nocell.io`,
        authHost: `auth.relaygo.com`,
        id: ``,
    }
};
class Vars {
    get env() {
        if (process.env.RELAY_ENV) {
            if (process.env.RELAY_ENV !== `qa` && process.env.RELAY_ENV !== `pro`) {
                throw new Error(`RELAY_ENV must be set to either "qa" or "pro"`);
            }
            else {
                return process.env.RELAY_ENV;
            }
        }
        else {
            return `qa`;
        }
    }
    get host() {
        const h = process.env.RELAY_HOST || config[this.env].host;
        if (!h.includes(this.env)) {
            process.env.RELAY_ENV && console.error(`RELAY_ENV=${process.env.RELAY_ENV}`);
            process.env.RELAY_HOST && console.error(`RELAY_HOST=${process.env.RELAY_HOST}`);
            console.error(`Host and environment must align`);
            throw new Error(`Environment / host mismatch`);
        }
        else {
            return h;
        }
    }
    get apiUrl() {
        return this.host.startsWith(`http`) ? this.host : `https://${this.host}`;
    }
    get apiHost() {
        if (this.host.startsWith(`http`)) {
            const u = new url_1.URL(this.host);
            if (u.host)
                return u.host;
        }
        return `${this.host}`;
    }
    get authHost() {
        return config[this.env].authHost;
    }
    get authUrl() {
        return `https://${this.authHost}`;
    }
    get authId() {
        return config[this.env].id;
    }
    get authRedirectPort() {
        return 8079;
    }
    get authRedirectHost() {
        return `http://localhost:${this.authRedirectPort}`;
    }
    get authRedirectUri() {
        return `${this.authRedirectHost}/authorization-code/callback`;
    }
    get stratusUrl() {
        return `https://all-qa-api-proxy.nocell.io/stratus/rest`;
    }
}
exports.Vars = Vars;
exports.vars = new Vars();
